import { Component, Input, Output, EventEmitter } from '@angular/core';
import { DomSanitizer, SafeHtml } from '@angular/platform-browser';
import { NzModalModule } from 'ng-zorro-antd/modal';
import { NzButtonModule } from 'ng-zorro-antd/button';
import { CommonModule, DatePipe } from '@angular/common';
import { JobModel } from '../../../../data-access/model/jobModel.model';

@Component({
  selector: 'app-view-job',
  templateUrl: './JobDetail.component.html',
  standalone: true,
  imports: [
    NzModalModule,
    NzButtonModule,
    DatePipe,
    CommonModule
  ]
})
export class ViewJobComponent {
  @Input() showViewModalComponent: boolean  = false;
  @Output() close = new EventEmitter<void>();
  @Input() jobData: JobModel.Job | null = null;

  constructor(private sanitizer: DomSanitizer) {}

  handleOk(): void {
    this.close.emit();
  }

  handleCancel(): void {
    this.close.emit();
  }

  getSanitizedDescription(description: string | null | undefined): SafeHtml {
    return description ? this.sanitizer.bypassSecurityTrustHtml(description) : 'N/A';
  }

  getSanitizedHowToApply(how_to_apply: string | null | undefined): SafeHtml {
    return how_to_apply ? this.sanitizer.bypassSecurityTrustHtml(how_to_apply) : 'N/A';
  }
}
