import { Injectable } from '@angular/core';
import { HttpClient, HttpHeaders, HttpParams, HttpRequest } from '@angular/common/http';
import { Observable } from 'rxjs';
import { environment } from '../../../../environments/environment.development';
import { JobModel } from '../model/jobModel.model';
import { ResponseResult, Rows } from '../../../shared/data-access/interface/response.type';


@Injectable({
  providedIn: 'root',
})
export class JobService {
  apiUrl = environment.API_DOMAIN + '/jobs';
  apiUrlById = environment.API_DOMAIN + '/jobById';
  constructor(private http: HttpClient) {}

  jobsGet(): Observable<ResponseResult<Rows<JobModel.Job>>> {
    return this.http.get<ResponseResult<Rows<JobModel.Job>>>(this.apiUrl);
  }

  addingNewJob(data: JobModel.JobRequest): Observable<ResponseResult<JobModel.Job>> {
    return this.http.post<ResponseResult<JobModel.Job>>(this.apiUrl, data);
  }
  deleteJob(id: string): Observable<ResponseResult<JobModel.Job>> {
     const url = `${this.apiUrl}/${id}`;
    return this.http.delete<ResponseResult<JobModel.Job>>(url);
  }
  editJob(data: JobModel.Job): Observable<ResponseResult<JobModel.Job>> {
    const url = `${this.apiUrl}/${data.id}`;
    return this.http.put<ResponseResult<JobModel.Job>>(url, data);
  }
  getJobById(id: string): Observable<ResponseResult<JobModel.Job>> {
    const url = `${this.apiUrlById}/${id}`;
    return this.http.get<ResponseResult<JobModel.Job>>(url);
  }

}
