// JobListCard.component.ts

import {
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Component,
  OnInit,
} from "@angular/core";
import { NzDividerModule } from "ng-zorro-antd/divider";
import { NzGridModule } from "ng-zorro-antd/grid";
import { JobModel } from "../../../+admin/data-access/model/jobModel.model";
import { JobService } from "../../data-access/service/Job.service";
import { tap } from "rxjs/operators";
import { CommonModule } from "@angular/common";
import { NzListModule } from "ng-zorro-antd/list";
import { NzCardModule } from "ng-zorro-antd/card";
import { NzTableModule } from "ng-zorro-antd/table";
import { NzPaginationModule } from "ng-zorro-antd/pagination";
import { FormsModule } from "@angular/forms";
import { NzInputModule } from "ng-zorro-antd/input";
import { NzButtonModule } from "ng-zorro-antd/button";
import { NzIconModule } from "ng-zorro-antd/icon";
import { RouterLink } from "@angular/router";

@Component({
  selector: "app-home-list-job",
  templateUrl: "./JobList.component.html",
  imports: [
    CommonModule,
    FormsModule,
    NzDividerModule,
    NzGridModule,
    NzListModule,
    NzCardModule,
    NzTableModule,
    NzPaginationModule,
    NzInputModule,
    NzButtonModule,
    NzIconModule,
  ],
  standalone: true,
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class JobListCardComponent implements OnInit {
  listOfJob: JobModel.Job[] = [];
  filteredJobs: JobModel.Job[] = [];
  displayedJobs: JobModel.Job[] = [];
  searchTerm: string = "";

  currentPage: number = 1;
  pageSize: number = 10;

  constructor(
    private jobService: JobService,
    private _changeDetectorRef: ChangeDetectorRef
  ) {}

  ngOnInit() {
    this.fetchJobs();
  }

  fetchJobs(): void {
    this.jobService.jobsGet().pipe(
      tap((res) => {
        this.listOfJob = res.responseData?.rows as JobModel.Job[];
        this.filteredJobs = [...this.listOfJob];
        this.updateDisplayedJobs();
        this._changeDetectorRef.markForCheck();
      })
    ).subscribe();
  }

  search(): void {
    if (this.searchTerm.trim()) {
      const term = this.searchTerm.trim().toLowerCase();
      this.filteredJobs = this.listOfJob.filter((job) =>
        (job.title && job.title.toLowerCase().includes(term)) ||
        (job.type && job.type.toLowerCase().includes(term)) ||
        (job.location && job.location.toLowerCase().includes(term))
      );
    } else {
      this.filteredJobs = [...this.listOfJob];
    }
    this.currentPage = 1;
    this.updateDisplayedJobs();
    this._changeDetectorRef.markForCheck();
  }

  onPageChange(page: number): void {
    this.currentPage = page;
    this.updateDisplayedJobs();
    this._changeDetectorRef.markForCheck();
  }

  updateDisplayedJobs(): void {
    const startIndex = (this.currentPage - 1) * this.pageSize;
    const endIndex = startIndex + this.pageSize;
    this.displayedJobs = this.filteredJobs.slice(startIndex, endIndex);
  }
}
